Class: Chatwerk::Views::NoPackagesView

Inherits:
BaseView
  • Object
show all
Defined in:
lib/chatwerk/views/no_packages_view.rb

Instance Attribute Summary

Attributes inherited from BaseView

#data, #output

Instance Method Summary collapse

Methods inherited from BaseView

#initialize, render, #render

Constructor Details

This class inherits a constructor from Chatwerk::Views::BaseView

Dynamic Method Handling

This class handles dynamic methods through the method_missing method in the class Chatwerk::Views::BaseView

Instance Method Details

#template(has_packwerk_yml: false) ⇒ Object



6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
# File 'lib/chatwerk/views/no_packages_view.rb', line 6

def template(has_packwerk_yml: false)
  if has_packwerk_yml
    <<~MESSAGE
      0 packages found.
      `packwerk.yml` file exists in project root: #{Chatwerk::Helpers.pwd}

      * Check that the project root is correct.
      * Make sure that packwerk is initialized correctly.
      * Make sure at least one package is defined.
    MESSAGE
  else
    <<~MESSAGE
      This project does not appear to be using packwerk.
      `packwerk.yml` file does not exist in project root: #{Chatwerk::Helpers.pwd}

      * Check that the project root is correct.
      * Check to make sure that packwerk is installed and initialized correctly.
    MESSAGE
  end
end